%define uname   CGAL

%define soname  13
%define libname %mklibname %{name} %{soname}
%define devname %mklibname %{name} -d

Name:           cgal
Version:        4.11
Release:        %mkrel 1
Summary:        Computational Geometry Algorithms Library
Group:          System/Libraries
License:        LGPLv3+ and GPLv3+ and Boost
URL:            http://www.cgal.org
Source0:        https://github.com/CGAL/cgal/releases/download/releases%2F%{uname}-%{version}/%{uname}-%{version}.tar.xz
Source1:        README.Hello

BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  gmp-devel
BuildRequires:  mpfr-devel
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(zlib)

%description
The goal of the CGAL Open Source Project is to provide easy access
to efficient and reliable geometric algorithms in the form of a C++
library. CGAL is used in various areas needing geometric computation,
such as: computer graphics, scientific visualization, computer aided
design and modeling, geographic information systems, molecular biology,
medical imaging, robotics and motion planning, mesh generation, numerical
methods... More on the projects using CGAL web page.

#----------------------------------------------------------------------------

%package -n     %{libname}
Group:          System/Libraries
Summary:        Computational Geometry Algorithms Library

%description -n %{libname}
%{desc}

%files -n       %{libname}
%doc AUTHORS LICENSE LICENSE.FREE_USE LICENSE.LGPL LICENSE.GPL CHANGES README.Hello
%{_libdir}/lib%{uname}*.so.%{soname}*

#----------------------------------------------------------------------------

%package -n     %{devname}
Group:          Development/Libraries
Summary:        Development files and tools for CGAL applications
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       %{uname}-devel = %{version}-%{release}

%description -n %{devname}
This package provides the headers files and tools you may need to
develop applications using CGAL.

%files -n       %{devname}
%{_includedir}/%{uname}
%{_libdir}/lib%{uname}*.so
%{_libdir}/%{uname}
%dir %{_datadir}/%{uname}
%{_bindir}/%{name}*
%exclude %{_bindir}/%{name}_make_macosx_app
%{_mandir}/man1/%{name}_create_cmake_script.1*

#----------------------------------------------------------------------------

%package        demos-source
Group:          Documentation
Summary:        Examples and demos of CGAL algorithms
Requires:       %{devname} = %{version}-%{release}

%description    demos-source
This package provides the sources of examples and demos of CGAL algorithms.

%files          demos-source
%{_datadir}/%{uname}/demo
%{_datadir}/%{uname}/examples
%exclude %{_datadir}/%{uname}/*/*/skip_vcproj_auto_generation

#----------------------------------------------------------------------------

%prep
%setup -q -n %{uname}-%{version}
%apply_patches

cp %{SOURCE1} .
sed -i -e 's/LIBNAME/%{libname}/g' -e 's/DEVNAME/%{devname}/g' README.Hello

%build
%cmake -DCMAKE_BUILD_TYPE=Release \
       -DCGAL_INSTALL_LIB_DIR=%{_lib} \
       -DCGAL_INSTALL_DOC_DIR=
%make_build

%install
%make_install -C build

# Install demos and examples
mkdir -p %{buildroot}%{_datadir}/%{uname}
cp -a demo %{buildroot}%{_datadir}/%{uname}/demo
cp -a examples %{buildroot}%{_datadir}/%{uname}/examples


%changelog
* Fri Nov 09 2018 adrianomorselli <adrianomorselli> 4.11-1uplos2018
- imported for uplos
